import json
import logging
from pathlib import Path

import requests
from requests import Response

from anki_card_create.config.settings import settings
from anki_card_create.exceptions import MediaAdditionError
from anki_card_create.models.anki_note import AnkiNote
from anki_card_create.models.kanki_input import KankiInput
from anki_card_create.models.response import AnkiNoteResponse, AnkiSendMediaResponse
from anki_card_create.services.utils import (
    create_audio,
    create_message,
)

logging.basicConfig(level=logging.INFO)


class CardCreator:
    def __init__(self) -> None:
        pass

    def send_notes(self, kanki_input: KankiInput, audio: bool = True) -> list[AnkiNoteResponse]:
        """Send the Anki notes to the Anki collection.

        Args:
            kanki_input (KankiInput): An input of the Anki notes.
            audio (bool, optional): If True, create an audio file from the front side of the Anki note. Defaults to True.

        Raises:
            MediaAdditionError: If the audio file is not added to the Anki collection.

        Returns:
            List[AnkiNoteResponse]: A list of the response of the Anki notes creation.

        """
        response_json_list = []
        # Create mp3 for a given anki-note and send it to Anki's media folder if audio is True
        anki_notes = kanki_input.anki_notes
        for anki_note in anki_notes:
            if audio:
                # Create the mp3 file from the front side of the anki-note
                audio_path = create_audio(anki_note.front)

                # Send the mp3 to Anki's media folder
                media_response = self._send_media(audio_path)
                if media_response.error is not None:
                    raise MediaAdditionError(media_response)

                # Create a str for denoting the media file
                audio_str = f"[sound:{media_response.audio_file_name}]"

                # remove the audio file that has been sent:
                audio_path.unlink()
            else:
                audio_str = ""

            # Create the Anki-note creation payload from the provided Anki-note
            note = {
                "deckName": anki_note.deckName,
                "modelName": anki_note.modelName,
                "fields": {
                    "表面": anki_note.front + audio_str,
                    "裏面": anki_note.back,
                },
            }
            params = {"note": note}

            # Send the request to add note into the specified deck, using anki connector
            response = self._anki_invoke(action="addNote", params=params)

            # Parse the response and create the response message
            if audio:
                card_create_response = self._create_response(
                    anki_note=anki_note,
                    connector_response=response,
                    audio=media_response.audio_file_name,
                )
            else:
                card_create_response = self._create_response(
                    anki_note=anki_note,
                    connector_response=response,
                )
            # Append the response message into a list
            response_json_list.append(card_create_response)
            logging.info(create_message(card_create_response))

        return response_json_list

    def _send_media(self, audio_path: Path | str) -> AnkiSendMediaResponse:
        """Send the created mp3 file to Anki collection folder (collection.media/).

        Args:
            audio_path (Union[Path, str]): _description_

        Returns:
            AnkiSendMediaResponse: _description_

        """
        # Convert the path into a Path datatype
        if not isinstance(audio_path, Path):
            audio_path = Path(audio_path)

        # Create the payload fot the anki connector request
        audio_filename = audio_path.name.__str__()
        audio_file_path = audio_path.__str__()
        params = {
            "filename": audio_filename,
            "path": audio_file_path,
        }

        # Send the request
        response = self._anki_invoke(action="storeMediaFile", params=params)

        return AnkiSendMediaResponse(
            audio_path=audio_file_path,
            audio_file_name=audio_filename,
            status_code=response.status_code,
            result=json.loads(response.text)["result"],
            error=json.loads(response.text)["error"],
        )

    def _anki_invoke(self, action: str, params: dict) -> Response:
        return requests.post(
            settings.api_url,
            json={"action": action, "version": 6, "params": params},
            timeout=30,
        )

    @staticmethod
    def _create_response(
        anki_note: AnkiNote,
        connector_response: requests.Response,
        audio: str | None = None,
    ) -> AnkiNoteResponse:
        response_json = connector_response.json()
        response_json["status_code"] = connector_response.status_code

        anki_note_dict = anki_note.model_dump()
        anki_note_dict.update(
            {
                "status_code": response_json["status_code"],
                "audio": audio,
                "result": response_json["result"],
                "error": response_json["error"],
            }
        )

        return AnkiNoteResponse(**anki_note_dict)



from langdetect import detect
from pydantic import BaseModel, model_validator

from anki_card_create.config import InputLang, TranslatedLang, settings


class AnkiNote(BaseModel):
    """Schema for the input to create an Anki card."""

    deckName: str = settings.deck_name
    modelName: str = settings.model_name
    front: str
    back: str | None = None
    sentence: str | None = None
    translated_sentence: str | None = None
    audio: str | None = None
    frontLang: InputLang = settings.using_lang
    backLang: TranslatedLang = settings.translate_lang

    @model_validator(mode="after")
    def check_languages(self):
        """Validate the detected languages of the input fields."""
        front_lang = self.frontLang
        # back_lang = self.backLang

        # Detect languages of `front` and `back` fields
        detected_front_lang = detect(self.front)
        # detected_back_lang = detect(self.back)

        # Validate detected languages against expected languages
        if front_lang != detected_front_lang:
            raise ValueError(
                f"Expected language for 'front' field is '{front_lang}', but detected '{detected_front_lang}'."
            )

        return self



from anki_card_create.card_creator import CardCreator
from anki_card_create.models.kanki_input import KankiInput


def test_add_note_to_anki(setup_anki_mock, global_data):
    # Assuming 'add_note_to_anki' is a function in your module that makes the post request
    kanki_input = KankiInput.from_input_word(
        input_str="죄송합니다",
        deck_name=global_data["deck_name"],
        model_name=global_data["model_name"],
    )

    # Call the function that makes the API request
    card_creator = CardCreator()
    response_list = card_creator.send_notes(kanki_input=kanki_input, audio=False)

    # Check that the response is as expected
    # assert response.json() == expected_response
    assert response_list[0].status_code == 200



import logging
import os
from pathlib import Path

import pytest

from anki_card_create.card_creator import CardCreator
from anki_card_create.models.kanki_input import KankiInput

logger = logging.getLogger(__name__)


@pytest.fixture
def anki2_path() -> Path:
    return Path(os.getenv("ANKI2_PATH"))


def test_send_anki_note_not_audio(global_data: dict[str, str | Path], create_test_data):
    """TESTCASE1: Send the created notes to the specified deck, without generating audios"""
    kanki_input = KankiInput.from_txt(
        data_fname=global_data["dir_path"] / global_data["test_file_name"],
        deck_name=global_data["deck_name"],
        model_name=global_data["model_name"],
    )

    card_creator = CardCreator()
    response_list = card_creator.send_notes(kanki_input=kanki_input, audio=False)
    assert len(response_list) == 2
    assert response_list[0].status_code == 200
    assert response_list[1].status_code == 200


def test_send_audio(global_data, create_test_audio, anki2_path):
    """TESTCASE2: Send the audio files to the Anki collection directory, without attaching it to the ankicard"""
    audio_path = global_data["dir_path"] / create_test_audio
    kanki_input = KankiInput.from_input_word(
        input_str="죄송합니다",
        deck_name=global_data["deck_name"],
        model_name=global_data["model_name"],
    )
    card_creator = CardCreator()
    response = card_creator._send_media(audio_path)
    assert response.error is None
    assert response.audio_file_name == global_data["audio_name"]
    # remove the audio file after testing
    # mp3_path = anki2_path / response.audio_file_name
    # os.remove(mp3_path.__str__())


def test_send_anki_note_with_audio(global_data, anki2_path):
    """TESTCASE3: Create an Anki card with audio"""
    kanki_input = KankiInput.from_input_word(
        input_str=global_data["test_word"],
        deck_name=global_data["deck_name"],
        model_name=global_data["model_name"],
    )
    card_creator = CardCreator()
    response_list = card_creator.send_notes(kanki_input=kanki_input, audio=True)
    logger.info(anki2_path / response_list[0].audio)
    assert response_list[0].status_code == 200
    # os.remove(anki2_path / response_list[0].audio)



from enum import Enum
from pathlib import Path

from pydantic import ConfigDict, Field
from pydantic_settings import BaseSettings

DIR_PATH = Path(__file__).resolve().parent.parent
API_URL = "http://127.0.0.1:8765"
MP3_PATH = DIR_PATH / "data"


class InputLang(str, Enum):
    ko = "ko"


class TranslatedLang(str, Enum):
    en = "en"
    ja = "ja"


class Config(BaseSettings):
    dir_path: Path = Field(
        default=DIR_PATH,
        description="The directory path for the application.",
    )

    mp3_path: Path = Field(
        default=DIR_PATH / "data",
        description="The directory path for the TTS generate audios.",
    )
    api_url: str = Field(
        default=API_URL,
        description="The url for AnkiConnector API",
    )
    deck_name: str = Field(
        default="korean",
        description="Target deck name",
    )
    model_name: str = Field(
        default="Basic (裏表反転カード付き)+sentense",
        description="The model name of the card being sent to Anki.",
    )

    ai: bool = False

    using_lang: InputLang = Field(
        default=InputLang.ko,
        description="The default input language.",
    )

    translate_lang: TranslatedLang = Field(
        default=TranslatedLang.ja,
        description="The translating language.",
    )
    model_config = ConfigDict(protected_namespaces=("settings_",))


settings = Config()



import os
from pathlib import Path

import pytest
from navertts import NaverTTS


@pytest.fixture(scope="session")
def global_data() -> dict[str, Path | str | list[str]]:
    return {
        "dir_path": Path(__file__).resolve().parent,
        "test_word": "안녕하세요",
        "test_word_in_txt": ["죄송합니다", "이거 얼마예요"],
        "test_file_name": "test_data.txt",
        "deck_name": "test",
        "model_name": "Basic (裏表反転カード付き)+sentense",
        "audio_name": "naver_hello_korean_test.mp3",
    }


@pytest.fixture
def response_anki_note(global_data: dict[str, Path | str | list[str]]) -> dict[str, int | str | None]:
    """A fixture to return the expected response from the Anki API."""
    # status_code: int
    # result: Union[None, int]
    # error: Union[None, str]
    # deckName: str = DECK_NAME
    # modelName: str = MODEL_NAME
    # front: str
    # back: str = None
    # sentence: Optional[str] = None
    # translated_sentence: Optional[str] = None
    # audio: Optional[str] = None
    # frontLang: str = "ko"
    return {
        "status_code": 200,
        "result": 1496198395707,
        "error": None,
        "deckName": global_data["deck_name"],
        "front": global_data["test_word"],
        "modelName": global_data["model_name"],
    }


@pytest.fixture
def setup_anki_mock(mocker, response_anki_note):
    # Mock requests.post to return a mock response object with .json() method
    mock_anki_invoke = mocker.patch("anki_card_create.card_creator.card_creator.CardCreator._anki_invoke")

    # Define the side effect function to handle different actions
    def anki_invoke_side_effect(action, params):
        if action == "addNote":
            expected_response = {
                "result": 1496198395707,
                "error": None,
            }
            return mocker.Mock(status_code=200, json=lambda: expected_response)
        if action == "storeMediaFile":
            expected_response = {
                "result": "test.mp3",
                "error": None,
            }
            return mocker.Mock(status_code=200, json=lambda: expected_response)
        return mocker.Mock(status_code=400, json=lambda: {"error": "not expected actions"})

    mock_anki_invoke.side_effect = anki_invoke_side_effect

    return mocker


@pytest.fixture(scope="module")
def create_test_data(global_data) -> None:
    """Create the test data at the file path being specified"""
    input_word = global_data["test_word_in_txt"]
    file_path = global_data["dir_path"] / global_data["test_file_name"]
    with open(file_path, "w") as f:
        for i, word in enumerate(input_word):
            if i > 0:
                f.write("\n")
            f.write(word)
    yield
    os.remove(file_path)  # Cleanup after the module tests are done


@pytest.fixture(scope="module")
def create_test_audio(global_data) -> str:
    tts = NaverTTS(global_data["test_word"])
    audio_name = global_data["dir_path"] / global_data["audio_name"]
    tts.save(audio_name)
    yield audio_name
    os.remove(audio_name)  # Cleanup after the module tests are done



from anki_card_create.models.translator_input import TranslatorInput
from anki_card_create.services.translators import TranslationTool


def test_translation_tool():
    tool = TranslationTool(TranslatorInput(source="ko", target="ja", ai=False))
    assert tool.translate("안녕") == "こんにちは"



from anki_card_create.models.response import AnkiSendMediaResponse


class MediaAdditionError(Exception):
    """Exception raised when adding media fails."""

    def __init__(self, response: AnkiSendMediaResponse, message="Failed to add media"):
        self.status_code = response.status_code
        message = response.error
        self.message = f"{message}. Status code: {self.status_code}"
        super().__init__(self.message)



from abc import ABC, abstractmethod

from deep_translator import GoogleTranslator

from anki_card_create.models.translator_input import TranslatorInput


class TranslatorStrategy(ABC):
    @abstractmethod
    def translate(self, word: str) -> str | None:
        pass


class SimpleGoogleTranslatorStrategy:
    def __init__(self, translation_input: TranslatorInput) -> None:
        self._translator = GoogleTranslator(
            source=translation_input.source,
            target=translation_input.target,
        )

    def translate(self, word: str) -> str | None:
        return self._translator.translate(word)


class AITranslatorStrategy:
    def __init__(self, translation_input: TranslatorInput) -> None:
        self._translator = translation_input

    def translate(self, word: str) -> str | None:
        raise NotImplementedError("AI translation is not implemented yet.")


class TranslationTool:
    def __init__(self, translation_input: TranslatorInput):
        # Save the AI flag
        self._strategy = self._init_strategy(translation_input)

    def _init_strategy(self, input: TranslatorInput):
        if not input.ai:
            return SimpleGoogleTranslatorStrategy(input)
        return AITranslatorStrategy(input)

    def translate(self, word: str) -> str | None:
        return self._strategy.translate(word)



import argparse
import logging
from pathlib import Path

from anki_card_create.card_creator import CardCreator
from anki_card_create.config import settings
from anki_card_create.models.kanki_input import KankiInput

logger = logging.getLogger(__name__)


def get_args_parser(known=False) -> argparse.Namespace:
    """Get the arguments parser for the command line interface."""
    parser = argparse.ArgumentParser("Create Anki flash cards.")
    group = parser.add_mutually_exclusive_group(required=True)

    group.add_argument(
        "-f",
        "--file",
        help="File containing text for Anki cards.",
    )
    group.add_argument(
        "-w",
        "--word",
        help="The vocabulary for Anki cards.",
    )

    parser.add_argument(
        "-d",
        "--deck_name",
        default=settings.deck_name,
        help="Name of the Anki deck to which the cards will be added.",
    )

    parser.add_argument(
        "-m",
        "--model_name",
        default=settings.model_name,
        help="Name of the Anki card model to which the cards will be added.",
    )

    return parser.parse_known_args()[0] if known else parser.parse_args()


def main() -> None:
    """Create Anki flash cards from the input word or file."""
    args = get_args_parser(known=True)
    logger.info(f"deck name: {args.deck_name}; card model: {args.model_name}")

    # Create notes according to the input word
    if args.file:
        kanki_input = KankiInput.from_txt(
            data_fname=Path() / args.file,
            deck_name=args.deck_name,
            model_name=args.model_name,
        )
    else:
        kanki_input = KankiInput.from_input_word(
            input_str=args.word,
            deck_name=args.deck_name,
            model_name=args.model_name,
        )

    # Send the notes to Anki with the audio
    card_creator = CardCreator()
    card_creator.send_notes(kanki_input=kanki_input, audio=True)


if __name__ == "__main__":
    main()



import logging
import sys
from argparse import Namespace

import pytest

from anki_card_create.cli.main import get_args_parser
from anki_card_create.config import settings

logger = logging.getLogger(__name__)


@pytest.mark.parametrize(
    "args, expected",
    [
        pytest.param(
            ["--file", "test.txt"],
            Namespace(
                file="test.txt",
                word=None,
                deck_name=settings.deck_name,
                model_name=settings.model_name,
            ),
        ),
        pytest.param(
            ["--word", "안녕하세요"],
            Namespace(
                file=None,
                word="안녕하세요",
                deck_name=settings.deck_name,
                model_name=settings.model_name,
            ),
        ),
        pytest.param(
            ["--file", "test.txt", "--deck_name", "test"],
            Namespace(
                file="test.txt",
                word=None,
                deck_name="test",
                model_name=settings.model_name,
            ),
        ),
        pytest.param(
            ["--file", "test.txt", "--model_name", "TestModel"],
            Namespace(
                file="test.txt",
                word=None,
                deck_name=settings.deck_name,
                model_name="TestModel",
            ),
        ),
    ],
)
def test_get_args_parser(args, expected, monkeypatch):
    # Simulate command-line arguments
    monkeypatch.setattr(sys, "argv", ["prog"] + args)

    assert get_args_parser(known=True) == expected


# def test_main_word(monkeypatch, global_data, setup_anki_mock):
#     test_args = [
#         "prog",
#         "--w",
#         "죄송합니다",
#         "--deck_name",
#         global_data["deck_name"],
#         "--model_name",
#         global_data["model_name"],
#     ]

#     # Mimic sys.argv
#     # sys.argv[0] would be "죄송합니다" ... vice versa.
#     monkeypatch.setattr(sys, "argv", test_args)

#     # Execute the main function
#     main()


# def test_main_file(monkeypatch, create_test_data, global_data, setup_anki_mock):
#     input_file = global_data["dir_path"] / global_data["test_file_name"]
#     input_file = input_file.__str__()

#     test_args = [
#         "prog",
#         "--f",
#         input_file,
#         "--deck_name",
#         global_data["deck_name"],
#         "--model_name",
#         global_data["model_name"],
#     ]
#     # Mimic sys.argv
#     monkeypatch.setattr(sys, "argv", test_args)

#     # Execute the main function
#     main()



from pydantic import BaseModel

from anki_card_create.config import InputLang, TranslatedLang


class TranslatorInput(BaseModel):
    """A data model to create the translator module."""

    source: InputLang = InputLang.ko
    target: TranslatedLang = TranslatedLang.ja
    ai: bool = False



import uuid
from pathlib import Path

from navertts import NaverTTS

from anki_card_create.config import settings
from anki_card_create.models.response import AnkiNoteResponse


def create_message(card_create_response: AnkiNoteResponse) -> str:
    """Generate a readable message based on the response of Anki connector after sending the notes.

    Args:
        card_create_response (AnkiNoteResponse): _description_

    Returns:
        str: The message.

    """
    # Check if the deck exists and the note was added successfully
    if card_create_response.status_code == 200:
        word_being_sent = f"{card_create_response.front}, {card_create_response.back}"
        if card_create_response.error is not None:
            # Check if the error message indicates that the deck does not exist
            if "deck not found" in card_create_response.error:
                return word_being_sent + ":Error: Deck does not exist"
            return word_being_sent + f": Error: {card_create_response.error}"
        return word_being_sent + ": Note added successfully"
    return word_being_sent + ": Error adding note to deck"


def create_audio(text: str, path: Path | str = settings.mp3_path) -> Path:
    """Create an audio file (.mp3) for the input korean word. Based on Naver TTS API.

    Args:
        text (str): Korean word.
        path (Union[Path, str], optional): _description_. Defaults to MP3_PATH.

    Returns:
        Union[Path, str]: The path of the output audio file.
            For example: User/path/to/directory/naver_e9633695-8fce-4ea3-901a-489863a9214e.mp3

    """
    # texts = [note.front for note in self._anki_notes]
    if not isinstance(path, Path):
        path = Path(path)
    if not path.exists():
        path.mkdir(parents=True, exist_ok=True)
    tts = NaverTTS(text)
    audio_filename = path / f"naver_{uuid.uuid4()}.mp3"
    tts.save(audio_filename)
    return audio_filename



import logging
from pathlib import Path

from pydantic import BaseModel, ConfigDict

from anki_card_create.config import settings
from anki_card_create.models.anki_note import AnkiNote
from anki_card_create.models.translator_input import TranslatorInput
from anki_card_create.services.translators import TranslationTool

logging.basicConfig(level=logging.INFO)


class KankiInput(BaseModel):
    """A schema for the input of Kanki command line to create Anki notes."""

    # A list of Anki notes to be created
    anki_notes: list[AnkiNote]
    model_config = ConfigDict(protected_namespaces=("settings_",))

    @classmethod
    def from_input_word(
        cls,
        input_str: str,
        translated_word: str | None = None,
        deck_name: str = settings.deck_name,
        model_name: str = settings.model_name,
    ) -> "KankiInput":
        """Model the kanki input based on the given word.

        Args:
            input_str (str): A string of the front word.
            translated_word (str, optional): Back word of the Anki note. Defaults to None.
            deck_name (str, optional): The deck name that the created note will be sent. Defaults to settings.deck_name.
            model_name (str, optional): The model name that will be used to format the created note. Defaults to settings.model_name.

        Returns:
            KankiInput: _description_

        """
        # Create the Anki note model
        if translated_word is None:
            # If the translated word is not provided, translate the word
            # Create a translator
            translator_settings = TranslatorInput(
                source=settings.using_lang,
                target=settings.translate_lang,
                ai=settings.ai,
            )
            translator = TranslationTool(translator_settings)

            # Execute translation
            translated_word = translator.translate(input_str)

        # If the translated word is provided
        anki_note = AnkiNote(
            deckName=deck_name,
            modelName=model_name,
            front=input_str,
            back=translated_word,
        )

        anki_notes_list = [anki_note]
        return cls(anki_notes=anki_notes_list)

    @classmethod
    def from_txt(
        cls,
        data_fname: Path = settings.dir_path / "data" / "example.txt",
        deck_name: str = settings.deck_name,
        model_name: str = settings.model_name,
    ) -> "KankiInput":
        """Create a list of Anki note based on a file which contains multiple words.

        Args:
            data_fname (Path, optional): The input file path. Defaults to settings.dir_path/"data"/"example.txt".
            deck_name (str, optional): The deck name that the created note will be sent. Defaults to settings.deck_name.
            model_name (str, optional): The model name that will be used to format the created note. Defaults to settings.model_name.

        Returns:
            KankiInput: _description_

        """
        # Read the vocabularies from a given text file
        with data_fname.open("r") as f:
            rows = f.read().split("\n")

        # Allowing reading translated words if it is provided
        voc_list = []
        translated_list = []
        for n, row in enumerate(rows):
            split_row = row.split(",")
            if len(split_row) == 2:
                voc_list.append(split_row[0])
                translated_list.append(split_row[1])
            elif len(split_row) == 1:
                voc_list.append(split_row[0])
                translated_list.append(None)
            else:
                raise ValueError(f"Format of input file is not available at line {n + 1}: {row}")

        # Create a translator for translating the word
        translator_settings = TranslatorInput(
            source=settings.using_lang,
            target=settings.translate_lang,
            ai=settings.ai,
        )
        translator = TranslationTool(translator_settings)

        # Create anki notes one by one
        anki_notes_list = []
        for word, translated in zip(voc_list, translated_list, strict=False):
            # If the word is not empty, create an Anki note
            try:
                # Validate the read word first.
                # It the word is not korean, raising errors
                anki_note = AnkiNote(
                    deckName=deck_name,
                    modelName=model_name,
                    front=word,
                )

                # Create the back side (translation) of the Ankinote
                if not translated:
                    # Translate the word into japanese if translated word is not provided
                    translated = translator.translate(word)

                anki_note.back = translated

                # Append the anki note into a list
                anki_notes_list.append(anki_note)
            except Exception as e:
                # If the word is not valid, skip it
                logging.warning(f"Error at line {n + 1}: {word} - {e}; skipping...")
                continue

        return cls(anki_notes=anki_notes_list)



from pydantic import BaseModel, ConfigDict

from anki_card_create.models.anki_note import AnkiNote


class AnkiNoteResponse(AnkiNote):
    """Response model for sending the created notes to the Anki DB."""

    status_code: int
    result: None | int
    error: None | str
    audio: str | None = None
    model_config = ConfigDict(from_attributes=True)


class AnkiSendMediaResponse(BaseModel):
    """Response after sending the created mp3 file to Anki collection folder."""

    audio_path: str
    audio_file_name: str
    status_code: int
    result: None | str = None
    error: None | str = None



import logging

from anki_card_create.config import settings
from anki_card_create.models.anki_note import AnkiNote
from anki_card_create.models.kanki_input import KankiInput
from anki_card_create.models.translator_input import TranslatorInput
from anki_card_create.services.translators import TranslationTool

# TODO: will remove after applying DI
translator_settings = TranslatorInput(
    source=settings.using_lang,
    target=settings.translate_lang,
    ai=settings.ai,
)
translator = TranslationTool(translator_settings)

logger = logging.getLogger(__name__)


def test_anki_note_model():
    """TESTCASE1: Create a note by manually input the text"""
    note = AnkiNote(
        deckName="korean",
        modelName="Basic (裏表反転カード付き)+sentense",
        front="안녕하세요",
        back="こんにちは",
    )

    assert note.deckName == "korean"
    assert note.modelName == "Basic (裏表反転カード付き)+sentense"
    assert note.front == "안녕하세요"
    assert note.back == "こんにちは"
    assert note.frontLang == "ko"


def test_anki_note_model_no_back():
    """TESTCASE2: Create a note by manually input the text without back"""
    note = AnkiNote(
        deckName="korean",
        modelName="Basic (裏表反転カード付き)+sentense",
        front="안녕하세요",
    )

    assert note.deckName == "korean"
    assert note.modelName == "Basic (裏表反転カード付き)+sentense"
    assert note.front == "안녕하세요"
    assert note.frontLang == "ko"


def test_create_anki_notes_from_txt(global_data, create_test_data):
    """TESTCASE3: Create anki notes from a given txt file."""
    logger.info("TESTCASE3")
    logger.info(global_data["dir_path"] / global_data["test_file_name"])

    anki_notes = KankiInput.from_txt(
        data_fname=global_data["dir_path"] / global_data["test_file_name"],
    ).anki_notes

    assert len(anki_notes) == 2
    assert anki_notes[0].front == "죄송합니다"
    assert anki_notes[1].front == "이거 얼마예요"
    assert anki_notes[0].back == translator.translate("죄송합니다")
    assert anki_notes[1].back == translator.translate("이거 얼마예요")


def test_create_anki_notes_from_input(global_data):
    """TESTCASE4: Create anki notes from a single input"""
    anki_notes = KankiInput.from_input_word(
        input_str="죄송합니다",
        deck_name=global_data["deck_name"],
        model_name=global_data["model_name"],
    ).anki_notes
    assert len(anki_notes) == 1
    assert anki_notes[0].front == "죄송합니다"
    assert anki_notes[0].back == translator.translate("죄송합니다")
